@@ -15,6 +15,7 @@ use Drupal\views\Entity\View;
  * Create, view, edit, delete, and change shortcut links.
  *
  * @group shortcut
+ * @group #slow
  */
 class ShortcutLinksTest extends ShortcutTestBase {
 
@@ -70,7 +71,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     // Test the add shortcut form UI. Test that the base field description is
     // there.
     $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
-    $this->assertRaw('The location this shortcut points to.');
+    $this->assertSession()->pageTextContains('The location this shortcut points to.');
 
     // Check that each new shortcut links where it should.
     foreach ($test_cases as $test_path) {
@@ -79,9 +80,10 @@ class ShortcutLinksTest extends ShortcutTestBase {
         'title[0][value]' => $title,
         'link[0][uri]' => $test_path,
       ];
-      $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, t('Save'));
+      $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+      $this->submitForm($form_data, 'Save');
       $this->assertSession()->statusCodeEquals(200);
-      $this->assertText(t('Added a shortcut for @title.', ['@title' => $title]));
+      $this->assertSession()->pageTextContains('Added a shortcut for ' . $title . '.');
       $saved_set = ShortcutSet::load($set->id());
       $paths = $this->getShortcutInformation($saved_set, 'link');
       $this->assertContains('internal:' . $test_path, $paths, 'Shortcut created: ' . $test_path);
@@ -100,8 +102,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
       // Test the node routes with parameters.
       $entity->save();
       $loaded = Shortcut::load($entity->id());
-      $this->assertEqual($entity->link->uri, $loaded->link->uri);
-      $this->assertEqual($entity->link->options, $loaded->link->options);
+      $this->assertEquals($entity->link->uri, $loaded->link->uri);
+      $this->assertEquals($entity->link->options, $loaded->link->options);
     }
 
     // Log in as non admin user, to check that access is checked when creating
@@ -112,30 +114,34 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'title[0][value]' => $title,
       'link[0][uri]' => '/admin',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertRaw(t("The path '@link_path' is inaccessible.", ['@link_path' => '/admin']));
+    $this->assertSession()->pageTextContains("The path '/admin' is inaccessible.");
 
     $form_data = [
       'title[0][value]' => $title,
       'link[0][uri]' => '/node',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->linkExists($title, 0, 'Shortcut link found on the page.');
 
     // Create a new shortcut set and add a link to it.
     $this->drupalLogin($this->adminUser);
     $edit = [
       'label' => $this->randomMachineName(),
-      'id' => strtolower($this->randomMachineName()),
+      'id' => $this->randomMachineName(),
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/add-set', $edit, t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/add-set');
+    $this->submitForm($edit, 'Save');
     $title = $this->randomMachineName();
     $form_data = [
       'title[0][value]' => $title,
       'link[0][uri]' => '/admin',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $edit['id'] . '/add-link', $form_data, t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $edit['id'] . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->statusCodeEquals(200);
   }
 
@@ -143,8 +149,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
    * Tests that the "add to shortcut" and "remove from shortcut" links work.
    */
   public function testShortcutQuickLink() {
-    \Drupal::service('theme_installer')->install(['seven']);
-    $this->config('system.theme')->set('admin', 'seven')->save();
+    \Drupal::service('theme_installer')->install(['claro']);
+    $this->config('system.theme')->set('admin', 'claro')->save();
     $this->config('node.settings')->set('use_admin_theme', '1')->save();
     $this->container->get('router.builder')->rebuild();
 
@@ -153,7 +159,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Test the "Add to shortcuts" link.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Cron.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Cron.');
     $this->assertSession()->linkExists('Cron', 0, 'Shortcut link found on page');
 
     $this->drupalGet('admin/structure');
@@ -162,7 +168,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     // Test the "Remove from shortcuts" link.
     $this->clickLink('Cron');
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText('The shortcut Cron has been deleted.');
+    $this->assertSession()->pageTextContains('The shortcut Cron has been deleted.');
     $this->assertSession()->linkNotExists('Cron', 'Shortcut link removed from page');
 
     $this->drupalGet('admin/structure');
@@ -172,39 +178,38 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Test the "Add to shortcuts" link for a page generated by views.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for People.');
+    $this->assertSession()->pageTextContains('Added a shortcut for People.');
     $this->assertShortcutQuickLink('Remove from Default shortcuts');
 
     // Test the "Remove from  shortcuts" link for a page generated by views.
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText('The shortcut People has been deleted.');
+    $this->assertSession()->pageTextContains('The shortcut People has been deleted.');
     $this->assertShortcutQuickLink('Add to Default shortcuts');
 
     // Test two pages which use same route name but different route parameters.
     $this->drupalGet('node/add/page');
     // Add Shortcut for Basic Page.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Create Basic page.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Create Basic page.');
     // Assure that Article does not have its shortcut indicated as set.
     $this->drupalGet('node/add/article');
-    $link = $this->xpath('//a[normalize-space()=:label]', [':label' => 'Remove from Default shortcuts']);
-    $this->assertTrue(empty($link), 'Link Remove to Default shortcuts not found for Create Article page.');
+    $this->assertSession()->elementNotExists('xpath', "//a[normalize-space()='Remove from Default shortcuts']");
     // Add Shortcut for Article.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Create Article.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Create Article.');
 
-    $this->config('system.theme')->set('default', 'seven')->save();
+    $this->config('system.theme')->set('default', 'claro')->save();
     $this->drupalGet('node/' . $this->node->id());
     $title = $this->node->getTitle();
 
     // Test the "Add to shortcuts" link for node view route.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText(new FormattableMarkup('Added a shortcut for @title.', ['@title' => $title]));
+    $this->assertSession()->pageTextContains("Added a shortcut for $title.");
     $this->assertShortcutQuickLink('Remove from Default shortcuts');
 
     // Test the "Remove from shortcuts" link for node view route.
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText(new FormattableMarkup('The shortcut @title has been deleted.', ['@title' => $title]));
+    $this->assertSession()->pageTextContains("The shortcut $title has been deleted.");
     $this->assertShortcutQuickLink('Add to Default shortcuts');
 
     \Drupal::service('module_installer')->install(['block_content']);
@@ -214,15 +219,12 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'revision' => FALSE,
     ])->save();
     // Test page with HTML tags in title.
-    $this->drupalGet('admin/structure/block/block-content/manage/basic');
-    $page_title = new FormattableMarkup('Edit %label custom block type', ['%label' => 'Basic block']);
-    $this->assertRaw($page_title);
+    $this->drupalGet('admin/structure/block-content/manage/basic');
+    $page_title = "Edit Basic block block type";
+    $this->assertSession()->pageTextContains($page_title);
     // Add shortcut to this page.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertRaw(new FormattableMarkup('Added a shortcut for %title.', [
-      '%title' => trim(strip_tags($page_title)),
-    ]));
-
+    $this->assertSession()->pageTextContains("Added a shortcut for {$page_title}.");
   }
 
   /**
@@ -236,12 +238,13 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $new_link_name], t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id());
+    $this->submitForm(['title[0][value]' => $new_link_name], 'Save');
     $saved_set = ShortcutSet::load($set->id());
     $titles = $this->getShortcutInformation($saved_set, 'title');
     $this->assertContains($new_link_name, $titles, 'Shortcut renamed: ' . $new_link_name);
     $this->assertSession()->linkExists($new_link_name, 0, 'Renamed shortcut link appears on the page.');
-    $this->assertText(t('The shortcut @link has been updated.', ['@link' => $new_link_name]));
+    $this->assertSession()->pageTextContains('The shortcut ' . $new_link_name . ' has been updated.');
   }
 
   /**
@@ -255,12 +258,16 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $shortcut->getTitle(), 'link[0][uri]' => $new_link_path], t('Save'));
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id());
+    $this->submitForm([
+      'title[0][value]' => $shortcut->getTitle(),
+      'link[0][uri]' => $new_link_path,
+    ], 'Save');
     $saved_set = ShortcutSet::load($set->id());
     $paths = $this->getShortcutInformation($saved_set, 'link');
     $this->assertContains('internal:' . $new_link_path, $paths, 'Shortcut path changed: ' . $new_link_path);
-    $this->assertLinkByHref($new_link_path, 0, 'Shortcut with new path appears on the page.');
-    $this->assertText(t('The shortcut @link has been updated.', ['@link' => $shortcut->getTitle()]));
+    $this->assertSession()->linkByHrefExists($new_link_path, 0, 'Shortcut with new path appears on the page.');
+    $this->assertSession()->pageTextContains('The shortcut ' . $shortcut->getTitle() . ' has been updated.');
   }
 
   /**
@@ -287,7 +294,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id() . '/delete', [], 'Delete');
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id() . '/delete');
+    $this->submitForm([], 'Delete');
     $saved_set = ShortcutSet::load($set->id());
     $ids = $this->getShortcutInformation($saved_set, 'id');
     $this->assertNotContains($shortcut->id(), $ids, 'Successfully deleted a shortcut.');
@@ -308,30 +316,27 @@ class ShortcutLinksTest extends ShortcutTestBase {
    */
   public function testNoShortcutLink() {
     // Change to a theme that displays shortcuts.
-    \Drupal::service('theme_installer')->install(['seven']);
+    \Drupal::service('theme_installer')->install(['claro']);
     $this->config('system.theme')
-      ->set('default', 'seven')
+      ->set('default', 'claro')
       ->save();
 
     $this->drupalGet('page-that-does-not-exist');
-    $result = $this->xpath('//a[contains(@class, "shortcut-action--add")]');
-    $this->assertTrue(empty($result), 'Add to shortcuts link was not shown on a page not found.');
+    // Test that add to shortcuts link is not shown on a page not found.
+    $this->assertSession()->elementNotExists('xpath', '//a[contains(@class, "shortcut-action--add")]');
 
     // The user does not have access to this path.
     $this->drupalGet('admin/modules');
-    $result = $this->xpath('//a[contains(@class, "shortcut-action--add")]');
-    $this->assertTrue(empty($result), 'Add to shortcuts link was not shown on a page the user does not have access to.');
+    $this->assertSession()->elementNotExists('xpath', '//a[contains(@class, "shortcut-action--add")]');
 
     // Verify that the testing mechanism works by verifying the shortcut link
     // appears on admin/content.
     $this->drupalGet('admin/content');
-    $result = $this->xpath('//a[contains(@class, "shortcut-action--remove")]');
-    $this->assertTrue(!empty($result), 'Remove from shortcuts link was shown on a page the user does have access to.');
+    $this->assertSession()->elementExists('xpath', '//a[contains(@class, "shortcut-action--remove")]');
 
     // Verify that the shortcut link appears on routing only pages.
     $this->drupalGet('router_test/test2');
-    $result = $this->xpath('//a[contains(@class, "shortcut-action--add")]');
-    $this->assertTrue(!empty($result), 'Add to shortcuts link was shown on a page the user does have access to.');
+    $this->assertSession()->elementExists('xpath', '//a[contains(@class, "shortcut-action--add")]');
   }
 
   /**
@@ -339,9 +344,9 @@ class ShortcutLinksTest extends ShortcutTestBase {
    */
   public function testAccessShortcutsPermission() {
     // Change to a theme that displays shortcuts.
-    \Drupal::service('theme_installer')->install(['seven']);
+    \Drupal::service('theme_installer')->install(['claro']);
     $this->config('system.theme')
-      ->set('default', 'seven')
+      ->set('default', 'claro')
       ->save();
 
     // Add cron to the default shortcut set.
@@ -368,7 +373,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->drupalLogin($this->drupalCreateUser([
       'access toolbar', 'access shortcuts', 'administer site configuration',
     ]));
-    $this->clickLink('Shortcuts', 0, 'Shortcut link found on page.');
+    $this->clickLink('Shortcuts');
     $this->assertSession()->linkExists('Cron', 0, 'Cron shortcut link found on page.');
 
     $this->verifyAccessShortcutsPermissionForEditPages();
@@ -387,20 +392,19 @@ class ShortcutLinksTest extends ShortcutTestBase {
     ]));
     $this->drupalGet(Url::fromRoute('<front>'));
     $shortcuts = $this->cssSelect('#toolbar-item-shortcuts-tray .toolbar-menu a');
-    $this->assertEqual($shortcuts[0]->getText(), 'Add content');
-    $this->assertEqual($shortcuts[1]->getText(), 'All content');
+    $this->assertEquals('Add content', $shortcuts[0]->getText());
+    $this->assertEquals('All content', $shortcuts[1]->getText());
     foreach ($this->set->getShortcuts() as $shortcut) {
       $shortcut->setWeight($shortcut->getWeight() * -1)->save();
     }
     $this->drupalGet(Url::fromRoute('<front>'));
     $shortcuts = $this->cssSelect('#toolbar-item-shortcuts-tray .toolbar-menu a');
-    $this->assertEqual($shortcuts[0]->getText(), 'All content');
-    $this->assertEqual($shortcuts[1]->getText(), 'Add content');
+    $this->assertEquals('All content', $shortcuts[0]->getText());
+    $this->assertEquals('Add content', $shortcuts[1]->getText());
   }
 
   /**
-   * Tests that the 'access shortcuts' permission is required for shortcut set
-   * administration page access.
+   * Tests the 'access shortcuts' permission for shortcut set administration.
    */
   private function verifyAccessShortcutsPermissionForEditPages() {
     // Create a user with customize links and switch sets permissions  but
@@ -409,8 +413,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'customize shortcut links',
       'switch shortcut sets',
     ];
-    $noaccess_user = $this->drupalCreateUser($test_permissions);
-    $this->drupalLogin($noaccess_user);
+    $no_access_user = $this->drupalCreateUser($test_permissions);
+    $this->drupalLogin($no_access_user);
 
     // Verify that set administration pages are inaccessible without the
     // 'access shortcuts' permission.
@@ -418,13 +422,12 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->assertSession()->statusCodeEquals(403);
     $this->drupalGet('admin/config/user-interface/shortcut/manage/default');
     $this->assertSession()->statusCodeEquals(403);
-    $this->drupalGet('user/' . $noaccess_user->id() . '/shortcuts');
+    $this->drupalGet('user/' . $no_access_user->id() . '/shortcuts');
     $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
-   * Tests that the 'access shortcuts' permission is required to access the
-   * shortcut block.
+   * Tests the 'access shortcuts' permission with the shortcut block.
    */
   public function testShortcutBlockAccess() {
     // Creates a block instance and place in a region through api.
@@ -458,19 +461,13 @@ class ShortcutLinksTest extends ShortcutTestBase {
    *   (optional) A message to display with the assertion. Do not translate
    *   messages: use new FormattableMarkup() to embed variables in the message text, not
    *   t(). If left blank, a default message will be displayed.
-   * @param string $group
-   *   (optional) The group this message is in, which is displayed in a column
-   *   in test output. Use 'Debug' to indicate this is debugging output. Do not
-   *   translate this string. Defaults to 'Other'; most tests do not override
-   *   this default.
    *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
+   * @internal
    */
-  protected function assertShortcutQuickLink($label, $index = 0, $message = '', $group = 'Other') {
+  protected function assertShortcutQuickLink(string $label, int $index = 0, string $message = ''): void {
     $links = $this->xpath('//a[normalize-space()=:label]', [':label' => $label]);
-    $message = ($message ? $message : new FormattableMarkup('Shortcut quick link with label %label found.', ['%label' => $label]));
-    return $this->assert(isset($links[$index]), $message, $group);
+    $message = ($message ? $message : (string) new FormattableMarkup('Shortcut quick link with label %label found.', ['%label' => $label]));
+    $this->assertArrayHasKey($index, $links, $message);
   }
 
 }
